@@ -1,9 +1,11 @@
 use super::config::{Config, KEYWORDS_REGEX, REGEX_TABLE};
 use super::datatypes::*;
 use regex::Regex;
+use std::collections::HashSet;
 use std::ffi::OsString;
-use std::fs::read_dir;
-use std::io::prelude::*;
+use std::fs::{self, read_dir, OpenOptions};
+use std::io::{prelude::*, BufReader};
+use std::sync::{Arc, RwLock};
 use std::{io::Result, path::Path, path::PathBuf, thread};
 
 /// Vector of all pathbufs
@@ -141,17 +143,29 @@ fn file_checker(files: &mut Files, path: &Path, filetypes: &[OsString], filetype
 /// Filter this line
 fn filter_line(line: &str, line_num: usize, re: &Regex) -> Option<Crumb> {
     match re.captures(line) {
-        Some(content) => Some(Crumb {
-            line_num,
-            keyword: None,
-            content: content[2].to_string(),
-        }),
+        Some(content) => Some(Crumb::new(line_num, None, content[2].to_string())),
         None => None,
     }
 }
 
 /// Operate this file
-fn op_file(file: File, kwreg: &Option<Regex>) -> Result<Option<Bread>> {
+fn op_file(file: File, kwreg: &Option<Regex>, conf: Arc<RwLock<Config>>) -> Result<Option<Bread>> {
+    let breads = bake_bread(file, kwreg)?;
+    if !conf.read().unwrap().delete {
+        Ok(breads)
+    } else {
+        match breads {
+            Some(bb) => {
+                clean_the_crumbs(bb)?;
+                Ok(None)
+            }
+            None => Ok(None),
+        }
+    }
+}
+
+/// make bread for this file
+fn bake_bread(file: File, kwreg: &Option<Regex>) -> Result<Option<Bread>> {
     // start to read file
     let mut buf = vec![];
     let file_p = file.to_string();
@@ -191,7 +205,7 @@ fn op_file(file: File, kwreg: &Option<Regex>) -> Result<Option<Bread>> {
                         Some(ref mut h) => {
                             if h.has_tail() {
                                 // if head has tail, add this line to head, continue
-                                h.add_tail(&cb);
+                                h.add_tail(cb);
                                 ss.clear(); // before continue, clear temp
                                 continue;
                             } else {
@@ -229,9 +243,56 @@ fn op_file(file: File, kwreg: &Option<Regex>) -> Result<Option<Bread>> {
     }
 }
 
-pub fn handle_files(conf: &Config) -> impl Iterator<Item = Bread> {
+/// clean crumbs and re-write the file
+pub fn clean_the_crumbs(Bread { file_path, crumbs }: Bread) -> Result<()> {
+    let f = fs::File::open(&file_path)?;
+    let reader = BufReader::new(f).lines();
+
+    let all_delete_lines = crumbs
+        .iter()
+        .map(|crumb| crumb.all_lines_num())
+        .flatten()
+        .collect();
+    let finish_deleted = delete_nth_lines(reader, all_delete_lines)?
+        .into_iter()
+        .map(|line| line.into_bytes());
+
+    let mut new_file = OpenOptions::new()
+        .write(true)
+        .truncate(true)
+        .open(file_path.clone())?;
+
+    for line in finish_deleted {
+        new_file.write_all(&line)?;
+        new_file.write_all(b"\n")?
+    }
+
+    println!("cleaned the crumbs in {}", file_path);
+    Ok(())
+}
+
+fn delete_nth_lines(
+    f: impl Iterator<Item = Result<String>>,
+    ns: HashSet<usize>,
+) -> Result<Vec<String>> {
+    let mut result = vec![];
+    for (_, ll) in f
+        .enumerate()
+        .filter(|(line_num, _)| !ns.contains(&(*line_num + 1)))
+    {
+        match ll {
+            Ok(s) => result.push(s),
+            Err(e) => return Err(e),
+        }
+    }
+
+    Ok(result)
+}
+
+/// entry function of main logic
+pub fn handle_files(conf: Config) -> impl Iterator<Item = Bread> {
     // first add all files in arguments
-    let mut all_files: Vec<File> = files_in_dir_or_file_vec(&conf.files, conf).unwrap();
+    let mut all_files: Vec<File> = files_in_dir_or_file_vec(&conf.files, &conf).unwrap();
 
     // split to groups
     let threads_num = 24;
@@ -243,13 +304,15 @@ pub fn handle_files(conf: &Config) -> impl Iterator<Item = Bread> {
     }
     groups.push(all_files.drain(0..).collect());
 
+    let conf = Arc::new(RwLock::new(conf));
     groups
         .into_iter()
-        .map(|fs| {
+        .map(move |fs| {
             let kwreg = KEYWORDS_REGEX.lock().unwrap().clone();
-            thread::spawn(move || {
+            let conf_c = Arc::clone(&conf);
+            thread::spawn(|| {
                 fs.into_iter()
-                    .map(|f| op_file(f, &kwreg).unwrap())
+                    .map(move |f| op_file(f, &kwreg, conf_c.clone()).unwrap())
                     .filter(|r| r.is_some())
                     .map(|q| q.unwrap())
                     .collect::<Vec<Bread>>()
