@@ -1,11 +1,11 @@
 use clap::Parser;
 use code_it_later_rs::{
+    args::Args,
     config::{self, parse_from_current_path_config},
-    fs_operation,
 };
 
 fn main() {
-    let commandline_args = config::Args::parse();
+    let commandline_args = Args::parse();
 
     #[cfg(debug_assertions)]
     dbg!(&commandline_args);
@@ -24,5 +24,5 @@ fn main() {
     #[cfg(debug_assertions)]
     dbg!(&args, &conf);
 
-    fs_operation::handle_files(&conf).for_each(|b| println!("{}", b));
+    code_it_later_rs::prompt(conf).unwrap();
 }
